==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/DavaMonitor/Lock.h <==
// class soot.dava.toolkits.base.DavaMonitor.Lock

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9d56446ac05aaf7f soot_dava_toolkits_base_DavaMonitor_Lock

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_DavaMonitor_Lock_H_
#define _JC_soot_dava_toolkits_base_DavaMonitor_Lock_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Thread$object;
struct _jc_java_util_LinkedList$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$object;

typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *);

// Virtual methods
extern struct _jc_java_lang_Thread$object *_jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$deQ$fd1aa41169dea6e0(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *);
extern void _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$enQ$84a1078d268ffcc0(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *);
extern struct _jc_java_lang_Thread$object *_jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$nextThread$77eeb4e27d4598c1(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method_info$deQ$fd1aa41169dea6e0;
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method_info$enQ$84a1078d268ffcc0;
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method_info$nextThread$77eeb4e27d4598c1;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods {
	struct _jc_java_lang_Thread$object	*(*deQ$fd1aa41169dea6e0)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *);
	void	(*enQ$84a1078d268ffcc0)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *);
	struct _jc_java_lang_Thread$object	*(*nextThread$77eeb4e27d4598c1)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods	soot_dava_toolkits_base_DavaMonitor_Lock;
};

// Vtype
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs {
	struct _jc_java_lang_Thread$object	*owner;
	struct _jc_java_util_LinkedList$object	*q;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs {
    _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs	soot_dava_toolkits_base_DavaMonitor_Lock;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs {
	jint	level;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs	soot_dava_toolkits_base_DavaMonitor_Lock;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object {
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype	*vtype;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype _jc_soot_dava_toolkits_base_DavaMonitor_Lock$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_DavaMonitor_Lock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_DavaMonitor_Lock$class_object;

#endif	/* _JC_soot_dava_toolkits_base_DavaMonitor_Lock_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/DavaMonitor/Lock.h <==
// class soot.dava.toolkits.base.DavaMonitor.Lock

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9d56446ac05aaf7f soot_dava_toolkits_base_DavaMonitor_Lock

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_DavaMonitor_Lock_H_
#define _JC_soot_dava_toolkits_base_DavaMonitor_Lock_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Thread$object;
struct _jc_java_util_LinkedList$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$object;

typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Thread$object *_jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$deQ$fd1aa41169dea6e0(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$enQ$84a1078d268ffcc0(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Thread$object *_jc_soot_dava_toolkits_base_DavaMonitor_Lock$method$nextThread$77eeb4e27d4598c1(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method_info$deQ$fd1aa41169dea6e0;
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method_info$enQ$84a1078d268ffcc0;
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_Lock$method_info$nextThread$77eeb4e27d4598c1;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods {
	struct _jc_java_lang_Thread$object	*(*deQ$fd1aa41169dea6e0)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;
	void	(*enQ$84a1078d268ffcc0)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Thread$object	*(*nextThread$77eeb4e27d4598c1)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vmethods	soot_dava_toolkits_base_DavaMonitor_Lock;
};

// Vtype
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs {
	struct _jc_java_lang_Thread$object	*owner;
	struct _jc_java_util_LinkedList$object	*q;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs {
    _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_refs	soot_dava_toolkits_base_DavaMonitor_Lock;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs {
	jint	level;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_DavaMonitor_Lock$sub_nonrefs	soot_dava_toolkits_base_DavaMonitor_Lock;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_Lock$object {
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype	*vtype;
	_jc_soot_dava_toolkits_base_DavaMonitor_Lock$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_DavaMonitor_Lock$vtype _jc_soot_dava_toolkits_base_DavaMonitor_Lock$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_DavaMonitor_Lock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_DavaMonitor_Lock$class_object;

#endif	/* _JC_soot_dava_toolkits_base_DavaMonitor_Lock_H_ */
